package org.sap;

import java.io.IOException;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Properties;
import org.json.*;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;

class RemindAppointment
{
    static Properties config;
    public static Properties loadProperties(String filePath) throws IOException {
        Properties prop = new Properties();
        InputStream input = null;
        ClassLoader loader = Thread.currentThread().getContextClassLoader();

        try {
            input = loader.getResourceAsStream(filePath);
            // load a properties file
            prop.load(input);
        } catch (IOException ex) {
            ex.printStackTrace();
            throw ex;
        } finally {
            if (input != null) {
                try {
                    input.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
        return prop;
    }

    public static void main(String[] args) throws IOException, ParseException
    {
        Doctor doctor = new Doctor();
        Patient patient = new Patient();
        Date bookingDate = null;
        SimpleDateFormat formatter = new SimpleDateFormat("yyyyMMddHHmm");
        String date = "";
        String time = "";
        int pid = 0;
        int did = 0;
        int sid = 0;

        config = loadProperties("config.properties");

        patient.setPatientID(pid++);
        patient.setPatientName(config.getProperty("patient_name"));
        doctor.setDoctorID(did++);
        doctor.setDoctorName(config.getProperty("doctor_name"));
        doctor.setSpecialization(new Specialization(sid++, config.getProperty("specialization")));
        date = config.getProperty("date");
        time = config.getProperty("time");
        bookingDate = formatter.parse(date + time);

        Appointment appointment = new Appointment(doctor, patient, bookingDate);
        String doctorName = appointment.getDoctor().getDoctorName();
        String patientName = appointment.getPatient().getPatientName();
        String specializationName = appointment.getDoctor().getSpecialization().getSpecializationName();
        Date appointmentDate = appointment.getDate();

        String appointmentMessage = "Mr./Mrs " + patientName + ", you have an appointment with " + doctorName + " (" + specializationName + ")" + " scheduled on " + appointmentDate;
        String appKey = config.getProperty("appKey"); //Replace with an App Key generated on the App Key area of the portal (Integrate - App Keys)
        String appSecret = config.getProperty("appSecret"); //Replace with an App Secret generated on the App Key area of the portal (Integrate - App Keys)
        String destinationNumber = config.getProperty("patient_number"); //substitute with your destination number.
        String baseUrl = config.getProperty("baseUrl"); //substitute with your destination number.
        MessageHandler handler = new MessageHandler(baseUrl);
        handler.sendSMS(appointmentMessage, destinationNumber, handler.getAccessToken(appKey, appSecret));
    }
    static String readFile(String path, Charset encoding)
    throws IOException
    {
        byte[] encoded = Files.readAllBytes(Paths.get(path));
        return new String(encoded, encoding);
    }
}